# -*- coding: utf-8 -*-
# author: Ethosa

from .CSharpToCpp import CSharpToCpp

__version__ = "0.0.7"
__copyright__ = "2019"
__authors__ = ["Ethosa", "Konard"]